# ifndef yyMakeParLoops
# define yyMakeParLoops

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 28 "MakeParLoops.puma" */


#include "VarDescriptor.h"



extern void (* MakeParLoops_Exit) ARGS ((void));

extern void MakeParLoops ARGS ((tTree t));

extern void BeginMakeParLoops ARGS ((void));
extern void CloseMakeParLoops ARGS ((void));

# endif
